@@ -186,7 +186,7 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
     except FileExistsError:
         a = 1
 
-    mpl.rcParams.update(pgf_with_latex)
+#    mpl.rcParams.update(pgf_with_latex)
     plt.ioff()
     fig,ax = plt.subplots()
     #graph2, = ax.plot(x,ytot,'--',label='k-point DOS', color='grey')
@@ -254,8 +254,83 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
 #    plt.show()
     return 
 
+def plot_k2(f, data, data_projected, indexes,freqs, max_Z, branches,  freq_res, title=''):
+    pgf_with_latex = {                      # setup matplotlib to use latex for output
+
+    "pgf.texsystem": "pdflatex",        # change this if using xetex or lautex
+
+    "text.usetex": True,                # use LaTeX to write all text
+
+    "font.family": "serif",
+
+    "font.serif": [],                   # blank entries should cause plots to inherit fonts from the document
+
+    "font.sans-serif": [],
+
+    "font.monospace": [],
+
+    "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
+
+    "legend.fontsize": 12,               # Make the legend/label fonts a little smaller
+
+    "xtick.labelsize": 16,
+
+    "ytick.labelsize": 16,
+
+    "figure.figsize": figsize(1.4),       # default fig size of 0.9 textwidth
+
+    "pgf.preamble": [
+
+        r"\usepackage[utf8x]{inputenc}",    # use utf8 fonts becasue your computer can handle it :)
+
+        r"\usepackage[T1]{fontenc}",        # plots will be generated using this preamble
+
+        ]
+
+    }
+
+    mpl.rcParams.update(pgf_with_latex)
+    N = len(data[0,:])
+    tot_branches = int(len(freqs[0][0,:]))
+
+    kk = np.linspace(0,1,N)
+    X, Y = np.meshgrid(kk,f)
+    fig, ax = plt.subplots()
     
-def plot_k(f, data, data_projected, indexes,freqs, max_Z, branches,  title=''):
+    if(len(branches) == tot_branches): #plot whole spectrum
+        print('Drawing the whole spectrum...')
+        ax.contourf(X,Y,data,100, vmax=max_Z)
+    else:
+        print('Drawing branches ', branches)
+        ax.contourf(X,Y,np.sum(data_projected[:,:,:], axis=1),100, vmax=max_Z)
+    
+    plt.xticks(kk,indexes)
+    
+    ax2 = plt.twinx()
+    ax2.set_ylabel('[Thz]')
+    num_dispersions = len(freqs)
+    colours = ['black', 'red']
+    for l in range(num_dispersions):
+        for j in range(tot_branches):
+            ax2.scatter(kk,freqs[l][:,j], marker='x', c=colours[l])
+        ax2.scatter(kk,freqs[l][:,tot_branches-1],  marker='x',  c=colours[l], label=title[l])
+    ax2.get_shared_y_axes().join(ax, ax2)
+    plt.ylim([f[0], f[-1]])
+    plt.xlim([kk[0], kk[-1]])
+    
+    handles, labels = ax.get_legend_handles_labels()
+    plt.legend(handles=handles, labels=labels)
+    ax.tick_params(axis='both', which='major', labelsize=15, width=2 , length=6, direction='in', top=True, left=True, bottom=True)
+    ax2.tick_params(axis='y', which='major', labelsize=15, width=2 , length=6, direction='in')
+    plt.rcParams['axes.linewidth'] = 2
+#    plt.show()
+    plt.suptitle('Spectrum branches '+str(branches))
+    fig.savefig('spectrum_branches_'+str(branches)+'.pdf')
+    fig.savefig('spectrum_branches_'+str(branches)+'.png')
+    return
+
+
+def plot_k(f, data, data_projected, indexes,freqs, max_Z, branches,  freq_res, title=''):
     """
     Plotting the dispersion from MD and from phonon theory.
     
@@ -310,25 +385,26 @@ def plot_k(f, data, data_projected, indexes,freqs, max_Z, branches,  title=''):
     N = len(data[0,:])
     offset = np.zeros(N) + f[0]
     df = f[1]-f[0]
+    molt = int(freq_res/df)
     tot_branches = int(len(freqs[0][0,:]))
     
     kk = np.linspace(0,1,N)
     dk = kk[1] - kk[0]
     
+    
 
 #    indexes = from_band(ks)
     
-
     #norm = [plt.cm.colors.Normalize(vmax=abs(data[0::1,l]).max(), vmin=-abs(data[0::1,l]).min()) for l in range(len(data[0,:]))]
     if(len(branches) == tot_branches): #plot whole spectrum
         print('Drawing the whole spectrum...')
         if(max_Z > np.max(data) or max_Z < 0.0):
-            max_Z = np.max(data)
+            max_Z = np.max(data[::molt,:])
         norm = plt.cm.colors.Normalize(vmax=max_Z, vmin=0)
-        for j in range(0,len(data[0::1,0])):  
+        for j in range(0,len(data[:,0]),molt):  
             # this is the whole spectrum
-            ax.bar(kk, np.repeat(df,N), bottom=offset-df/2,  color=plt.cm.Blues(norm(data[j,:])), tick_label=indexes, align='center', width=dk, alpha=None)
-            offset = offset + df
+            ax.bar(kk, np.repeat(df*molt,N), bottom=offset-df/2,  color=plt.cm.Blues(norm(data[j,:])), tick_label=indexes, align='center', width=dk, alpha=None)
+            offset = offset + df*molt
             
     else:   #print only those branches 
         if(max_Z > np.max(data_projected) or max_Z < 0.0):
@@ -352,11 +428,11 @@ def plot_k(f, data, data_projected, indexes,freqs, max_Z, branches,  title=''):
     ax2 = plt.twinx()
     ax2.set_ylabel('[Thz]')
     num_dispersions = len(freqs)
-    colours = ['blue', 'red']
+    colours = ['black', 'red']
     for l in range(num_dispersions):
         for j in range(tot_branches):
-            ax2.scatter(kk,freqs[l][:,j], marker='x', c=colours[l], s=100)
-        ax2.scatter(kk,freqs[l][:,tot_branches-1],  marker='x', s=100, c=colours[l], label=title[l])
+            ax2.scatter(kk,freqs[l][:,j], marker='x', c=colours[l])
+        ax2.scatter(kk,freqs[l][:,tot_branches-1],  marker='x',  c=colours[l], label=title[l])
     ax2.get_shared_y_axes().join(ax, ax2)
     
     
